@@ -6,7 +6,7 @@ from io import StringIO
 from datetime import timedelta
 import time
 
-def get_sessions(start, end):
+def get_sessions(start, end, user, password):
     start_date = datetime.strptime(start, '%Y%m%d%H%M%S')
     end_date = datetime.strptime(end, '%Y%m%d%H%M%S')
 
@@ -15,9 +15,9 @@ def get_sessions(start, end):
     days_query = (end_date - start_date).days
 
     if days_query < 6:
-        fb_url = 'https://my.parkfolio.com/drdirect.php'
-        fb_params = {'login': 'grandrapids_dr',
-                     'password': 'yZ9kjPBKNHzxd2dx',
+        fb_url = 'https://my.flowbird.io/drdirect.php'
+        fb_params = {'login': user,
+                     'password': password,
                      'report': 'transaction_history',
                      'startdate': start,
                      'enddate': end}
@@ -27,7 +27,7 @@ def get_sessions(start, end):
 
     else:
         flowbird_data = pd.DataFrame()
-        total_queries = math.ceil(days_query / 5)
+        total_queries = math.ceil(days_query / 5) - 1
         end_date = datetime.strftime(start_date + timedelta(days=5), '%Y%m%d235959')
         start_date = datetime.strftime(start_date, '%Y%m%d000000')
 
@@ -36,9 +36,9 @@ def get_sessions(start, end):
             if i > 0:
                 print('Waiting 70 seconds for next query to avoid API limits.')
                 time.sleep(70)
-            fb_url = 'https://my.parkfolio.com/drdirect.php'
-            fb_params = {'login': 'grandrapids_dr',
-                         'password': 'yZ9kjPBKNHzxd2dx',
+            fb_url = 'https://my.flowbird.io/drdirect.php'
+            fb_params = {'login': user,
+                         'password': password,
                          'report': 'transaction_history',
                          'startdate': start_date,
                          'enddate': end_date}
